`desc`: str (Optional)
: The description for the check

`substitute`: bool (Optional)
: Whether to [substitute](#environment-substitution) environment variables in
check values<br>
  __default__: True<br>
  __aliases__: ``substitute``, ``env_substitute``
